##  Basic View Controls
  * Zoom: Use your mouse wheel, track pad, or the zoom controls in the toolbar.
  * Pan: Click and drag the canvas to move the view.
  * Fit to screen: Choose the fit‑to‑screen icon to display the entire diagram.
